MotionTabBarController constructor

MotionTabBarController({
  1. int initialIndex = 0,
  2. Duration? animationDuration,
  3. required int length,
  4. required TickerProvider vsync,
})

Creates a MotionTabBarController.

length is the number of tabs and vsync is the ticker provider, usually the owning State (which must mix in TickerProviderStateMixin or SingleTickerProviderStateMixin).

Implementation

MotionTabBarController({
  int initialIndex = 0,
  Duration? animationDuration,
  required int length,
  required TickerProvider vsync,
}) : super(initialIndex: initialIndex, animationDuration: animationDuration, length: length, vsync: vsync);