ALPHA_OFF top-level constant
double
const ALPHA_OFF
Opacity of the icon when the tab is not selected.
Implementation
const double ALPHA_OFF = 0;
Opacity of the icon when the tab is not selected.
const double ALPHA_OFF = 0;