ALPHA_ON top-level constant
double
const ALPHA_ON
Opacity of the icon when the tab is selected.
Implementation
const double ALPHA_ON = 1;
Opacity of the icon when the tab is selected.
const double ALPHA_ON = 1;