ICON_OFF top-level constant
double
const ICON_OFF
Vertical alignment offset of the icon when the tab is not selected.
Implementation
const double ICON_OFF = -3;
Vertical alignment offset of the icon when the tab is not selected.
const double ICON_OFF = -3;