onTabChange property
set
onTabChange
(dynamic fx(int)?)
Sets the callback invoked whenever the tab index changes.
This is used internally by MotionTabBar; you normally do not need to set it yourself.
Implementation
set onTabChange(Function(int)? fx) {
_changeIndex = fx;
}