motion-tab-item library

A single tab item rendered inside a MotionTabBar.

Classes

MotionTabItem
A single tab item inside a MotionTabBar.

Constants

ALPHA_OFF → const double
Opacity of the icon when the tab is not selected.
ALPHA_ON → const double
Opacity of the icon when the tab is selected.
ANIM_DURATION → const int
Duration (in milliseconds) of the tab item animations.
ICON_OFF → const double
Vertical alignment offset of the icon when the tab is not selected.
ICON_ON → const double
Vertical alignment offset of the icon when the tab is selected.
TEXT_OFF → const double
Vertical alignment offset of the label when the tab is not selected.
TEXT_ON → const double
Vertical alignment offset of the label when the tab is selected.